==> gnome-db-0.2.3.tar.gz: gnome-db-0.2.3/lib/gnome-db-entry.h <==
/* GNOME DB library
 * Copyright (C) 1999-2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __gnome_db_entry_h__
#define __gnome_db_entry_h__ 1

#include <gnome.h>
#include <gda-recordset.h>

BEGIN_GNOME_DECLS

#define GNOME_DB_TYPE_ENTRY            (gnome_db_entry_get_type())
#define GNOME_DB_ENTRY(obj)            GTK_CHECK_CAST(obj, GNOME_DB_TYPE_ENTRY, GnomeDbEntry)
#define GNOME_DB_ENTRY_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GNOME_DB_TYPE_ENTRY, GnomeDbEntryClass)
#define GNOME_DB_IS_ENTRY(obj)         GTK_CHECK_TYPE(obj, GNOME_DB_TYPE_ENTRY)
#define GNOME_DB_IS_ENTRY_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GNOME_DB_TYPE_ENTRY))

typedef struct _GnomeDbEntry        GnomeDbEntry;
typedef struct _GnomeDbEntryClass   GnomeDbEntryClass;
typedef struct _GnomeDbEntryPrivate GnomeDbEntryPrivate;

struct _GnomeDbEntry {
	GtkEntry             entry;
	GnomeDbEntryPrivate* priv;
};

struct _GnomeDbEntryClass {
	GtkEntryClass parent_class;
};

GtkType        gnome_db_entry_get_type      (void);
GtkWidget*     gnome_db_entry_new           (Gda_Recordset *recset, gint col);
Gda_Recordset* gnome_db_entry_get_recordset (GnomeDbEntry *entry);
void           gnome_db_entry_set_recordset (GnomeDbEntry *entry, Gda_Recordset *recset, gint col);
const gchar*   gnome_db_entry_get_text      (GnomeDbEntry *entry);
void           gnome_db_entry_set_text      (GnomeDbEntry *entry, const gchar *txt);

END_GNOME_DECLS

#endif

==> gnome-db-0.2.94.tar.gz: gnome-db-0.2.94/lib/gnome-db-entry.h <==
/* GNOME DB library
 * Copyright (C) 1999-2000 Rodrigo Moya
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __gnome_db_entry_h__
#define __gnome_db_entry_h__ 1

#include <gtk/gtkentry.h>
#include <libgnome/gnome-defs.h>
#include <gda-recordset.h>

BEGIN_GNOME_DECLS

#define GNOME_DB_TYPE_ENTRY            (gnome_db_entry_get_type())
#define GNOME_DB_ENTRY(obj)            GTK_CHECK_CAST(obj, GNOME_DB_TYPE_ENTRY, GnomeDbEntry)
#define GNOME_DB_ENTRY_CLASS(klass)    GTK_CHECK_CLASS_CAST(klass, GNOME_DB_TYPE_ENTRY, GnomeDbEntryClass)
#define GNOME_DB_IS_ENTRY(obj)         GTK_CHECK_TYPE(obj, GNOME_DB_TYPE_ENTRY)
#define GNOME_DB_IS_ENTRY_CLASS(klass) (GTK_CHECK_CLASS_TYPE((klass), GNOME_DB_TYPE_ENTRY))

typedef struct _GnomeDbEntry        GnomeDbEntry;
typedef struct _GnomeDbEntryClass   GnomeDbEntryClass;
typedef struct _GnomeDbEntryPrivate GnomeDbEntryPrivate;

struct _GnomeDbEntry {
	GtkEntry             entry;
	GnomeDbEntryPrivate* priv;
};

struct _GnomeDbEntryClass {
	GtkEntryClass parent_class;
};

GtkType        gnome_db_entry_get_type      (void);
GtkWidget*     gnome_db_entry_new           (GdaRecordset *recset, gint col);
GdaRecordset* gnome_db_entry_get_recordset (GnomeDbEntry *entry);
void           gnome_db_entry_set_recordset (GnomeDbEntry *entry, GdaRecordset *recset, gint col);
const gchar*   gnome_db_entry_get_text      (GnomeDbEntry *entry);
void           gnome_db_entry_set_text      (GnomeDbEntry *entry, const gchar *txt);

END_GNOME_DECLS

#endif
